Test Datasets
=============

This contains a few small datasets for testing IO routines. The aim is to use these in unit tests. Files should be as
small as practical.

TODO - should we make these more interesting - e.g. our logo?
TODO - a repository of biological test datasets